==> apache-inlong-0.12.0-incubating-src.tar.gz: apache-inlong-0.12.0-incubating/inlong-manager/manager-service/src/main/java/org/apache/inlong/manager/service/workflow/consumption/NewConsumptionProcessDetailHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.service.workflow.consumption;

import org.apache.inlong.manager.workflow.core.ProcessDefinitionService;
import org.apache.inlong.manager.workflow.model.definition.Process;
import org.apache.inlong.manager.workflow.model.definition.ProcessDetailHandler;
import org.apache.inlong.manager.workflow.model.view.ProcessDetail;
import org.apache.inlong.manager.workflow.util.WorkflowFormParserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * New consumption process detail handler
 */
@Component
public class NewConsumptionProcessDetailHandler implements ProcessDetailHandler {

    @Autowired
    private ProcessDefinitionService processDefinitionService;

    @Override
    public ProcessDetail handle(ProcessDetail processDetail) {
        Process process = processDefinitionService.getByName(processDetail.getWorkflow().getName());

        NewConsumptionWorkflowForm workflowForm = WorkflowFormParserUtils
                .parseProcessForm(processDetail.getProcessInfo().getFormData().toString(), process);

        if (workflowForm == null) {
            return processDetail;
        }

        processDetail.getProcessInfo().setFormData(workflowForm);
        return processDetail;
    }
}

==> apache-inlong-1.0.0-incubating-src.tar.gz: apache-inlong-1.0.0-incubating/inlong-manager/manager-service/src/main/java/org/apache/inlong/manager/service/workflow/consumption/NewConsumptionProcessDetailHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.service.workflow.consumption;

import org.apache.inlong.manager.common.workflow.ProcessDefinitionService;
import org.apache.inlong.manager.common.model.definition.Process;
import org.apache.inlong.manager.common.model.definition.ProcessDetailHandler;
import org.apache.inlong.manager.common.model.view.ProcessDetail;
import org.apache.inlong.manager.workflow.util.WorkflowFormParserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * New consumption process detail handler
 */
@Component
public class NewConsumptionProcessDetailHandler implements ProcessDetailHandler {

    @Autowired
    private ProcessDefinitionService processDefinitionService;

    @Override
    public ProcessDetail handle(ProcessDetail processDetail) {
        Process process = processDefinitionService.getByName(processDetail.getWorkflow().getName());

        NewConsumptionWorkflowForm workflowForm = WorkflowFormParserUtils
                .parseProcessForm(processDetail.getProcessInfo().getFormData().toString(), process);

        if (workflowForm == null) {
            return processDetail;
        }

        processDetail.getProcessInfo().setFormData(workflowForm);
        return processDetail;
    }
}
